# SectionItem

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**data** | **object** |  | [optional] 
**display_type** | **str** |  | [optional] 
**end_col** | **int** |  | [optional] 
**field_id** | **str** |  | [optional] 
**field_name** | **str** |  | [optional] 
**field_type** | **str** |  | [optional] 
**header_style** | **object** |  | [optional] 
**index** | **int** |  | [optional] 
**start_col** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


